==> hierarchy_manager-3.0.5.tar.gz: hierarchy_manager/js/Plugin/jstree/hm.jstree.js <==
/**
 * @file
 * Hierarchy Manager jsTree JavaScript file.
 */

// Codes run both on normal page loads and when data is loaded by AJAX (or BigPipe!)
// @See https://www.drupal.org/docs/8/api/javascript-api/javascript-api-overview
(function($, Drupal) {
  Drupal.behaviors.hmJSTree = {
    attach: function(context, settings) {
      $(".hm-jstree", context)
        .once("jstreeBehavior")
        .each(function() {
          const treeContainer = $(this);
          const parentID = treeContainer.attr('parent-id');
          const searchTextID = (parentID) ? '#hm-jstree-search-' + parentID : '#hm-jstree-search';
          const optionsJson = treeContainer.attr("options");
          const dataURL = treeContainer.attr('data-source') + '&parent=0';
          const updateURL = treeContainer.attr('url-update');
          let reload = true;
          let rollback = false;
          let themes = {
              dots: false,
              name: 'default'
          };
          let options;

          if (optionsJson) {
            options = JSON.parse(optionsJson);
            if (options.theme) {
              themes = options.theme;
            }
          }
          // Ajax callback to refresh the tree.
          if (reload) {
            // Build the tree.
            treeContainer.jstree({
              core: {
                'check_callback' : function (operation, node, node_parent, node_position, more) {
                  return true;
                },
                data: {
                  url: function(node) {
                    return node.id === '#' ?
                        dataURL :
                        dataURL;
                  },
                  data: function(node) {
                    return node;
                  }
                },
                themes: themes,
                "multiple": false,
              },
              'dnd' : {
                'copy': false,
                'is_draggable' : function(node) {
                  let can_drag = node[0].data.draggable;
                  if (can_drag) {
                    return true;
                  }
                  else {
                    let drupalMessages = new Drupal.Message();
                    drupalMessages.clear();
                    drupalMessages.add(Drupal.t("Can't drag this item. It may because it has multiple parents or ancestors."), {type: 'warning'});
                    return false;
                  }
                }
              },
              search: {
                show_only_matches: true,
                "search_callback": function(str, node) {
                  //search for any of the words entered
                  var word, words = [];
                  var searchFor = str.toLowerCase().replace(/^\s+/g, '').replace(/\s+$/g, '');
                  if (searchFor.indexOf(' ') >= 0) {
                    words = searchFor.split(' ');
                  } else {
                    words = [searchFor];
                  }
                  for (var i = 0; i < words.length; i++) {
                    word = words[i];
                    if ((node.text || "").toLowerCase().indexOf(word) >= 0) {
                      return true;
                    }
                  }
                  return false;
                }
              },
              'sort' : function(a, b) {
                return parseInt(this.get_node(a).data.weight) > parseInt(this.get_node(b).data.weight) ? 1 : -1;
              },
              plugins: ["search", "dnd", "sort"]
            });

           // Node move event.
            treeContainer.on("move_node.jstree", function(event, data) {
              const thisTree = data.instance;
              const movedNode = data.node;
              const parent = data.parent === '#' ? 0 : data.parent;
              const parent_node = thisTree.get_node(data.parent);
              const old_parent = data.old_parent === '#' ? 0 : data.old_parent;
              const drupalMessages = new Drupal.Message();

              if (!rollback) {
                // Update the data on server side.
                $.post(updateURL, {
                  keys: [movedNode.id],
                  target: data.position,
                  parent: parent,
                  old_parent: old_parent,
                  old_position: data.old_position
                })
                  .done(function(response) {
                    if (response.result !== "success") {
                      alert("Server error:" + response.result);
                      rollback = true;
                      thisTree.move_node(movedNode, data.old_parent, data.old_position);
                    }
                    else {
                      if (parent === 0) {
                        var parentText = Drupal.t('root');
                      }
                      else {
                        var parentText = parent_node.text;
                      }
                      if (parent_node.data && !parent_node.data.draggable) {
                        // The parent node is not draggable.
                        // We have to update all duplicated nodes
                        // by refreshing the whole tree.
                        thisTree.refresh();
                      }
                      else {
                        // Update the nodes changed in the server side.
                        if (response.updated_nodes) {
                          let update_nodes = response.updated_nodes;
                          for (const id in update_nodes) {
                            let node = thisTree.get_node(id);
                            if (node) {
                              node.data.weight = update_nodes[id];
                            }
                          }
                          //Refresh the tree without reloading data from server.
                          thisTree.sort(parent_node, true);
                          thisTree.redraw(true);
                        }
                      }

                      let message = Drupal.t('@node is moved to position @position under @parent', {'@node': data.node.text, '@parent': parentText, '@position': data.position + 1});
                      // Inform user the movement.
                      drupalMessages.clear();
                      drupalMessages.add(message);
                    }
                  })
                  .fail(function() {
                    drupalMessages.clear();
                    drupalMessages.add(Drupal.t("Can't connect to the server."), {type: 'error'});
                    rollback = true;
                    thisTree.move_node(movedNode, data.old_parent, data.old_position);
                  });
              }
              else {
                rollback = false;
              }
            });

            treeContainer.on('ready.jstree open_node.jstree move_node.jstree search.jstree clear_search.jstree redraw.jstree', function (event, data) {
              Drupal.attachBehaviors(event.target);
            });

            // Search filter box.
            let to = false;
            $(searchTextID).keyup(function() {
              const searchInput = $(this);
              if (to) {
                clearTimeout(to);
              }
              to = setTimeout(function() {
                const v = searchInput.val();
                treeContainer.jstree(true).search(v);
              }, 250);
            });
          }
        });
    }
  };
})(jQuery, Drupal);

==> hierarchy_manager-3.1.1.tar.gz: hierarchy_manager/js/Plugin/jstree/hm.jstree.js <==
/**
 * @file
 * Hierarchy Manager jsTree JavaScript file.
 */

// Codes run both on normal page loads and when data is loaded by AJAX (or BigPipe!)
// @See https://www.drupal.org/docs/8/api/javascript-api/javascript-api-overview
(function($, Drupal) {
  Drupal.behaviors.hmJSTree = {
    attach: function(context, settings) {
      $(".hm-jstree", context)
        .once("jstreeBehavior")
        .each(function() {
          const treeContainer = $(this);
          const parentID = treeContainer.attr('parent-id');
          const searchTextID = (parentID) ? '#hm-jstree-search-' + parentID : '#hm-jstree-search';
          const optionsJson = treeContainer.attr("options");
          const dataURL = treeContainer.attr('data-source') + '&parent=0';
          const updateURL = treeContainer.attr('url-update');
          let reload = true;
          let rollback = false;
          let themes = {
              dots: false,
              name: 'default'
          };
          let options;

          if (optionsJson) {
            options = JSON.parse(optionsJson);
            if (options.theme) {
              themes = options.theme;
            }
          }
          // Ajax callback to refresh the tree.
          if (reload) {
            // Build the tree.
            treeContainer.jstree({
              core: {
                'check_callback' : function (operation, node, node_parent, node_position, more) {
                  return true;
                },
                data: {
                  url: function(node) {
                    return node.id === '#' ?
                        dataURL :
                        dataURL;
                  },
                  data: function(node) {
                    return node;
                  }
                },
                themes: themes,
                "multiple": false,
              },
              'dnd' : {
                'copy': false,
                'is_draggable' : function(node) {
                  let can_drag = node[0].data.draggable;
                  if (can_drag) {
                    return true;
                  }
                  else {
                    let drupalMessages = new Drupal.Message();
                    drupalMessages.clear();
                    drupalMessages.add(Drupal.t("Cannot drag this item, possibly because it has multiple parents or ancestors."), {type: 'warning'});
                    return false;
                  }
                }
              },
              search: {
                show_only_matches: true,
                "search_callback": function(str, node) {
                  //search for any of the words entered
                  var word, words = [];
                  var searchFor = str.toLowerCase().replace(/^\s+/g, '').replace(/\s+$/g, '');
                  if (searchFor.indexOf(' ') >= 0) {
                    words = searchFor.split(' ');
                  } else {
                    words = [searchFor];
                  }
                  for (var i = 0; i < words.length; i++) {
                    word = words[i];
                    if ((node.text || "").toLowerCase().indexOf(word) >= 0) {
                      return true;
                    }
                  }
                  return false;
                }
              },
              'sort' : function(a, b) {
                return parseInt(this.get_node(a).data.weight) > parseInt(this.get_node(b).data.weight) ? 1 : -1;
              },
              plugins: ["search", "dnd", "sort"]
            });

           // Node move event.
            treeContainer.on("move_node.jstree", function(event, data) {
              const thisTree = data.instance;
              const movedNode = data.node;
              const parent = data.parent === '#' ? 0 : data.parent;
              const parent_node = thisTree.get_node(data.parent);
              const old_parent = data.old_parent === '#' ? 0 : data.old_parent;
              const drupalMessages = new Drupal.Message();

              if (!rollback) {
                // Update the data on server side.
                $.post(updateURL, {
                  keys: [movedNode.id],
                  target: data.position,
                  parent: parent,
                  old_parent: old_parent,
                  old_position: data.old_position
                })
                  .done(function(response) {
                    if (response.result !== "success") {
                      alert("Server error:" + response.result);
                      rollback = true;
                      thisTree.move_node(movedNode, data.old_parent, data.old_position);
                    }
                    else {
                      if (parent === 0) {
                        var parentText = Drupal.t('root');
                      }
                      else {
                        var parentText = parent_node.text;
                      }
                      if (parent_node.data && !parent_node.data.draggable) {
                        // The parent node is not draggable.
                        // We have to update all duplicated nodes
                        // by refreshing the whole tree.
                        thisTree.refresh();
                      }
                      else {
                        // Update the nodes changed in the server side.
                        if (response.updated_nodes) {
                          let update_nodes = response.updated_nodes;
                          for (const id in update_nodes) {
                            let node = thisTree.get_node(id);
                            if (node) {
                              node.data.weight = update_nodes[id];
                            }
                          }
                          //Refresh the tree without reloading data from server.
                          thisTree.sort(parent_node, true);
                          thisTree.redraw(true);
                        }
                      }

                      let message = Drupal.t('@node is moved to position @position under @parent', {'@node': data.node.text, '@parent': parentText, '@position': data.position + 1});
                      // Inform user the movement.
                      drupalMessages.clear();
                      drupalMessages.add(message);
                    }
                  })
                  .fail(function() {
                    drupalMessages.clear();
                    drupalMessages.add(Drupal.t("Can't connect to the server."), {type: 'error'});
                    rollback = true;
                    thisTree.move_node(movedNode, data.old_parent, data.old_position);
                  });
              }
              else {
                rollback = false;
              }
            });

            treeContainer.on('ready.jstree open_node.jstree move_node.jstree search.jstree clear_search.jstree redraw.jstree', function (event, data) {
              Drupal.attachBehaviors(event.target);
            });

            // Search filter box.
            let to = false;
            $(searchTextID).keyup(function() {
              const searchInput = $(this);
              if (to) {
                clearTimeout(to);
              }
              to = setTimeout(function() {
                const v = searchInput.val();
                treeContainer.jstree(true).search(v);
              }, 250);
            });
          }
        });
    }
  };
})(jQuery, Drupal);
